]> git.ipfire.org Git - thirdparty/bash.git/blobdiff - pathexp.h
fix for SIGINT in sourced script
[thirdparty/bash.git] / pathexp.h
index 5f1731ad99b3b9a2d811d867a373f3e3d70b8ea3..183a2124c9d10115b79f8fbf595840741559beaa 100644 (file)
--- a/pathexp.h
+++ b/pathexp.h
@@ -1,22 +1,22 @@
 /* pathexp.h -- The shell interface to the globbing library. */
 
-/* Copyright (C) 1987-2005 Free Software Foundation, Inc.
+/* Copyright (C) 1987-2015 Free Software Foundation, Inc.
 
    This file is part of GNU Bash, the Bourne Again SHell.
 
-   Bash is free software; you can redistribute it and/or modify it under
-   the terms of the GNU General Public License as published by the Free
-   Software Foundation; either version 2, or (at your option) any later
-   version.
+   Bash is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
-   Bash is distributed in the hope that it will be useful, but WITHOUT ANY
-   WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-   for more details.
+   Bash is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License along
-   with Bash; see the file COPYING.  If not, write to the Free Software
-   Foundation, 59 Temple Place, Suite 330, Boston, MA 02111 USA. */
+   You should have received a copy of the GNU General Public License
+   along with Bash.  If not, see <http://www.gnu.org/licenses/>.
+*/
 
 #if !defined (_PATHEXP_H_)
 #define _PATHEXP_H_
@@ -32,6 +32,7 @@ extern char *glob_error_return;
 /* Flag values for quote_string_for_globbing */
 #define QGLOB_CVTNULL  0x01    /* convert QUOTED_NULL strings to '\0' */
 #define QGLOB_FILENAME 0x02    /* do correct quoting for matching filenames */
+#define QGLOB_REGEXP   0x04    /* quote an ERE for regcomp/regexec */
 
 #if defined (EXTENDED_GLOB)
 /* Flags to OR with other flag args to strmatch() to enabled the extended
@@ -42,9 +43,11 @@ extern char *glob_error_return;
 #endif /* !EXTENDED_GLOB */
 
 #define FNMATCH_IGNCASE                (match_ignore_case ? FNM_CASEFOLD : 0)
+#define FNMATCH_NOCASEGLOB     (glob_ignore_case ? FNM_CASEFOLD : 0)
 
 extern int glob_dot_filenames;
 extern int extended_glob;
+extern int glob_star;
 extern int match_ignore_case;  /* doesn't really belong here */
 
 extern int unquoted_glob_pattern_p __P((char *));
@@ -61,13 +64,14 @@ extern int unquoted_glob_pattern_p __P((char *));
    to match a filename should be performed. */
 extern char *quote_string_for_globbing __P((const char *, int));
 
-extern char *quote_globbing_chars __P((char *));
+extern int glob_char_p __P((const char *));
+extern char *quote_globbing_chars __P((const char *));
 
 /* Call the glob library to do globbing on PATHNAME. */
 extern char **shell_glob_filename __P((const char *));
 
 /* Filename completion ignore.  Used to implement the "fignore" facility of
-   tcsh and GLOBIGNORE (like ksh-93 FIGNORE).
+   tcsh, GLOBIGNORE (like ksh-93 FIGNORE), and EXECIGNORE.
 
    It is passed a NULL-terminated array of (char *)'s that must be
    free()'d if they are deleted.  The first element (names[0]) is the
@@ -83,7 +87,7 @@ struct ign {
 typedef int sh_iv_item_func_t __P((struct ign *));
 
 struct ignorevar {
-  char *varname;       /* FIGNORE or GLOBIGNORE */
+  char *varname;       /* FIGNORE, GLOBIGNORE, or EXECIGNORE */
   struct ign *ignores; /* Store the ignore strings here */
   int num_ignores;     /* How many are there? */
   char *last_ignoreval;        /* Last value of variable - cached for speed */